@@ -202,7 +202,6 @@ RESERVED = MatchFirst([
     IN,
     INNER,
     INTERSECT,
-    INTERVAL,
     IS_NOT,
     IS,
     JOIN,
@@ -221,7 +220,6 @@ RESERVED = MatchFirst([
     OUTER,
     OVER,
     PARTITION,
-    # PIVOT,
     PRIMARY,
     QUALIFY,
     REFERENCES,
@@ -235,7 +233,6 @@ RESERVED = MatchFirst([
     UNION,
     UNIQUE,
     UNNEST,
-    # UNPIVOT,
     USING,
     WHEN,
     WHERE,
